==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QGLXContext_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qopenglcontext_platform.h>)
#include <QtGui/qopenglcontext_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QOpenGLContext>
#include <QtGui/qopenglcontext.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(xcb_glx_plugin)



#endif // QT_CONFIG(xcb_glx_plugin)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QGLXContext::nativeContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QGLXContext_00024Impl_00024ConcreteWrapper_nativeContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb_glx_plugin)
        const QNativeInterface::QGLXContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QGLXContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QGLXContext::nativeContext()const", __qt_this)
        GLXContext __qt_return_value = __qt_this->nativeContext();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 0);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb_glx_plugin)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QGLXContext::fromNative(GLXContext,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QGLXContext_00024Impl_fromNative_1native_1GLXContext_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject configBasedContext0,
 QtJambiNativeID shareContext1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QGLXContext::fromNative(GLXContext,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb_glx_plugin)
        GLXContext __qt_configBasedContext0 = reinterpret_cast<GLXContext >(QtJambiAPI::convertQNativePointerToNative(__jni_env, configBasedContext0, 0));
        QOpenGLContext* __qt_shareContext1 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext1);
        QOpenGLContext* __qt_return_value = QNativeInterface::QGLXContext::fromNative(__qt_configBasedContext0, __qt_shareContext1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(configBasedContext0)
        Q_UNUSED(shareContext1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb_glx_plugin)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QGLXContext::fromNative(GLXContext,void*,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QGLXContext_00024Impl_fromNative_1native_1GLXContext_1void_1ptr_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject visualBasedContext0,
 jobject visualInfo1,
 QtJambiNativeID shareContext2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QGLXContext::fromNative(GLXContext,void*,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb_glx_plugin)
        GLXContext __qt_visualBasedContext0 = reinterpret_cast<GLXContext >(QtJambiAPI::convertQNativePointerToNative(__jni_env, visualBasedContext0, 0));
        void* __qt_visualInfo1 = reinterpret_cast<void* >(QtJambiAPI::convertQNativePointerToNative(__jni_env, visualInfo1, 1));
        QOpenGLContext* __qt_shareContext2 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext2);
        QOpenGLContext* __qt_return_value = QNativeInterface::QGLXContext::fromNative(__qt_visualBasedContext0, __qt_visualInfo1, __qt_shareContext2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(visualBasedContext0)
        Q_UNUSED(visualInfo1)
        Q_UNUSED(shareContext2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb_glx_plugin)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QGLXContext(){
    using namespace RegistryAPI;

#if QT_CONFIG(xcb_glx_plugin)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QGLXContext>("QNativeInterface::QGLXContext", "io/qt/gui/nativeinterface/QGLXContext");
    registerNativeInterface<QNativeInterface::QGLXContext>("io/qt/gui/nativeinterface/QGLXContext");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QGLXContext* _object = dynamic_cast<QNativeInterface::QGLXContext*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QGLXContext *object = reinterpret_cast<QNativeInterface::QGLXContext *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QGLXContext *object = reinterpret_cast<const QNativeInterface::QGLXContext *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(xcb_glx_plugin)

    registerNativeInterface("io/qt/gui/nativeinterface/QGLXContext", {});

#endif //QT_CONFIG(xcb_glx_plugin)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QGLXContext_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qopenglcontext_platform.h>)
#include <QtGui/qopenglcontext_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QOpenGLContext>
#include <QtGui/qopenglcontext.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(xcb_glx_plugin)



#endif // QT_CONFIG(xcb_glx_plugin)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QGLXContext::nativeContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QGLXContext_00024Impl_00024ConcreteWrapper_nativeContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb_glx_plugin)
        const QNativeInterface::QGLXContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QGLXContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QGLXContext::nativeContext()const", __qt_this)
        GLXContext __qt_return_value = __qt_this->nativeContext();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb_glx_plugin)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QGLXContext::fromNative(GLXContext,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QGLXContext_00024Impl_fromNative_1native_1GLXContext_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject configBasedContext0,
 QtJambiNativeID shareContext1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QGLXContext::fromNative(GLXContext,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb_glx_plugin)
        GLXContext __qt_configBasedContext0 = reinterpret_cast<GLXContext >(QtJambiAPI::convertQNativePointerToNative(__jni_env, configBasedContext0));
        QOpenGLContext* __qt_shareContext1 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext1);
        QOpenGLContext* __qt_return_value = QNativeInterface::QGLXContext::fromNative(__qt_configBasedContext0, __qt_shareContext1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(configBasedContext0)
        Q_UNUSED(shareContext1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb_glx_plugin)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QGLXContext::fromNative(GLXContext,void*,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QGLXContext_00024Impl_fromNative_1native_1GLXContext_1void_1ptr_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject visualBasedContext0,
 jobject visualInfo1,
 QtJambiNativeID shareContext2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QGLXContext::fromNative(GLXContext,void*,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(xcb_glx_plugin)
        GLXContext __qt_visualBasedContext0 = reinterpret_cast<GLXContext >(QtJambiAPI::convertQNativePointerToNative(__jni_env, visualBasedContext0));
        void* __qt_visualInfo1 = reinterpret_cast<void* >(QtJambiAPI::convertQNativePointerToNative(__jni_env, visualInfo1));
        QOpenGLContext* __qt_shareContext2 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext2);
        QOpenGLContext* __qt_return_value = QNativeInterface::QGLXContext::fromNative(__qt_visualBasedContext0, __qt_visualInfo1, __qt_shareContext2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(visualBasedContext0)
        Q_UNUSED(visualInfo1)
        Q_UNUSED(shareContext2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(xcb_glx_plugin)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QGLXContext(){
    using namespace RegistryAPI;

#if QT_CONFIG(xcb_glx_plugin)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QGLXContext>("QNativeInterface::QGLXContext", "io/qt/gui/nativeinterface/QGLXContext");
    registerNativeInterface<QNativeInterface::QGLXContext>("io/qt/gui/nativeinterface/QGLXContext");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QGLXContext* _object = dynamic_cast<QNativeInterface::QGLXContext*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QGLXContext *object = reinterpret_cast<QNativeInterface::QGLXContext *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QGLXContext *object = reinterpret_cast<const QNativeInterface::QGLXContext *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(xcb_glx_plugin)

    registerNativeInterface("io/qt/gui/nativeinterface/QGLXContext", {});

#endif //QT_CONFIG(xcb_glx_plugin)

}
